@@ -3,20 +3,21 @@ from typing import Dict, List, Optional, TYPE_CHECKING, Tuple
 
 from qtpy import QtCore, QtGui, QtWidgets
 
-from napari._qt.widgets.qt_extension2reader import Extension2ReaderTable
-from napari._qt.widgets.qt_highlight_preview import QtHighlightSizePreviewWidget
-from napari._qt.widgets.qt_keyboard_settings import ShortcutEditor
+from ...._qt.widgets.qt_extension2reader import Extension2ReaderTable
+from ...._qt.widgets.qt_highlight_preview import QtHighlightPreviewWidget
+from ...._qt.widgets.qt_keyboard_settings import ShortcutEditor
+from ...._qt.widgets.qt_font_size import QtFontSizeWidget
 
-from napari._vendor.qt_json_builder.qt_jsonschema_form.signal import Signal
-from napari._vendor.qt_json_builder.qt_jsonschema_form.utils import is_concrete_schema, iter_layout_widgets, state_property
+from .signal import Signal
+from .utils import is_concrete_schema, iter_layout_widgets, state_property
 
-from napari._qt.widgets.qt_plugin_sorter import QtPluginSorter
+from ...._qt.widgets.qt_plugin_sorter import QtPluginSorter
 
-from napari._qt.widgets.qt_spinbox import QtSpinBox
+from ...._qt.widgets.qt_spinbox import QtSpinBox
 
 
 if TYPE_CHECKING:
-    from napari._vendor.qt_json_builder.qt_jsonschema_form.form import WidgetBuilder
+    from .form import WidgetBuilder
 
 
 class SchemaWidgetMixin:
@@ -584,18 +585,18 @@ class ArraySchemaWidget(SchemaWidgetMixin, QtWidgets.QWidget):
         self.on_changed.emit(self.state)
 
 
-class HighlightSizePreviewWidget(
-    SchemaWidgetMixin, QtHighlightSizePreviewWidget
+class HighlightPreviewWidget(
+    SchemaWidgetMixin, QtHighlightPreviewWidget
 ):
     @state_property
-    def state(self) -> int:
+    def state(self) -> dict:
         return self.value()
 
     def setDescription(self, description: str):
         self._description.setText(description)
 
     @state.setter
-    def state(self, state: int):
+    def state(self, state: dict):
         self.setValue(state)
 
     def configure(self):
@@ -644,6 +645,40 @@ class Extension2ReaderWidget(SchemaWidgetMixin, Extension2ReaderTable):
         self.setGraphicsEffect(self.opacity)
         self.opacity.setOpacity(1)
 
+
+class FontSizeSchemaWidget(SchemaWidgetMixin, QtFontSizeWidget):
+    @state_property
+    def state(self) -> int:
+        return self.value()
+
+    @state.setter
+    def state(self, state: int):
+        self.setValue(state)
+
+    def configure(self):
+        self.valueChanged.connect(self.on_changed.emit)
+        self.opacity = QtWidgets.QGraphicsOpacityEffect(self)
+        self.setGraphicsEffect(self.opacity)
+        self.opacity.setOpacity(1)
+
+        minimum = 1
+        if "minimum" in self.schema:
+            minimum = self.schema["minimum"]
+            if self.schema.get("exclusiveMinimum"):
+                minimum += 1
+
+        maximum = 100
+        if "maximum" in self.schema:
+            maximum = self.schema["maximum"]
+            if self.schema.get("exclusiveMaximum"):
+                maximum -= 1
+
+        self.setRange(minimum, maximum)
+
+    def setDescription(self, description: str):
+        self.description = description
+
+
 class ObjectSchemaWidgetMinix(SchemaWidgetMixin):
     def __init__(
         self,
