@@ -4,6 +4,10 @@ import zarr
 from qtpy.QtCore import QCoreApplication
 
 from napari._tests.utils import skip_local_popups, skip_on_win_ci
+from napari._vispy.visuals.volume import Volume as VolumeNode
+from napari.components import ViewerModel
+from napari.layers.labels._labels_constants import IsoCategoricalGradientMode
+from napari.qt import QtViewer
 from napari.utils.interactions import mouse_press_callbacks
 
 
@@ -19,10 +23,10 @@ def make_labels_layer(array_type, shape):
         spec = {
             'driver': 'zarr',
             'kvstore': {'driver': 'memory'},
-            "metadata": {"chunks": chunks},
+            'metadata': {'chunks': chunks},
         }
         labels = ts.open(
-            spec, create=True, dtype="uint32", shape=shape
+            spec, create=True, dtype='uint32', shape=shape
         ).result()
     else:
         pytest.fail("array_type must be 'numpy', 'zarr', or 'tensorstore'")
@@ -31,7 +35,6 @@ def make_labels_layer(array_type, shape):
 
 
 @skip_local_popups
-@skip_on_win_ci
 @pytest.mark.parametrize('array_type', ['numpy', 'zarr', 'tensorstore'])
 def test_labels_painting(make_napari_viewer, array_type):
     """Check that painting labels paints on the canvas.
@@ -49,9 +52,8 @@ def test_labels_painting(make_napari_viewer, array_type):
 
 
 @skip_local_popups
-@skip_on_win_ci
 @pytest.mark.parametrize('array_type', ['numpy', 'zarr', 'tensorstore'])
-def test_labels_fill_slice(make_napari_viewer, array_type, qtbot):
+def test_labels_fill_slice(make_napari_viewer, array_type):
     """Check that painting labels paints only on current slice.
 
     This should work regardless of array type. See:
@@ -64,7 +66,6 @@ def test_labels_fill_slice(make_napari_viewer, array_type, qtbot):
     labels[2, :, :] = 1
     layer = viewer.add_labels(labels)
     layer.n_edit_dimensions = 3
-    qtbot.wait(10)
     QCoreApplication.instance().processEvents()
     layer.fill((1, 10, 10), 13, refresh=True)
     visual = viewer.window._qt_viewer.layer_to_visual[layer]
@@ -72,7 +73,6 @@ def test_labels_fill_slice(make_napari_viewer, array_type, qtbot):
 
 
 @skip_local_popups
-@skip_on_win_ci
 @pytest.mark.parametrize('array_type', ['numpy', 'zarr', 'tensorstore'])
 def test_labels_painting_with_mouse(
     MouseEvent, make_napari_viewer, array_type
@@ -99,3 +99,35 @@ def test_labels_painting_with_mouse(
     assert not np.any(visual.node._data)
     mouse_press_callbacks(layer, event)
     assert np.any(visual.node._data)
+
+
+@skip_local_popups
+@skip_on_win_ci
+def test_labels_iso_gradient_modes(qtbot):
+    """Check that we can set `iso_gradient_mode` with `iso_categorical` rendering (test shader)."""
+    # NOTE: this test currently segfaults on Windows CI, but confirmed working locally
+    # because it's a segfault, we have to skip instead of xfail
+    viewer = ViewerModel()
+    qt_viewer = QtViewer(viewer)
+    qt_viewer.show()
+    qtbot.addWidget(qt_viewer)
+
+    labels = make_labels_layer('numpy', shape=(32, 32, 32))
+    labels[14:18, 14:18, 14:18] = 1
+    layer = viewer.add_labels(labels)
+    visual = qt_viewer.layer_to_visual[layer]
+
+    viewer.dims.ndisplay = 3
+    QCoreApplication.instance().processEvents()
+    assert layer.rendering == 'iso_categorical'
+    assert isinstance(visual.node, VolumeNode)
+
+    layer.iso_gradient_mode = IsoCategoricalGradientMode.SMOOTH
+    QCoreApplication.instance().processEvents()
+    assert layer.iso_gradient_mode == 'smooth'
+    assert visual.node.iso_gradient_mode == 'smooth'
+
+    layer.iso_gradient_mode = IsoCategoricalGradientMode.FAST
+    QCoreApplication.instance().processEvents()
+    assert layer.iso_gradient_mode == 'fast'
+    assert visual.node.iso_gradient_mode == 'fast'
