@@ -1,9 +1,9 @@
 import copy
 import itertools
 import time
+from collections import defaultdict
 from dataclasses import dataclass
 from tempfile import TemporaryDirectory
-from typing import List
 
 import numpy as np
 import numpy.testing as npt
@@ -11,16 +11,19 @@ import pandas as pd
 import pytest
 import xarray as xr
 import zarr
-from numpy.core.numerictypes import issubdtype
-from numpy.testing import assert_array_almost_equal, assert_raises
 from skimage import data as sk_data
 
 from napari._tests.utils import check_layer_world_data_extent
 from napari.components import ViewerModel
+from napari.components.dims import Dims
 from napari.layers import Labels
 from napari.layers.labels._labels_constants import LabelsRendering
 from napari.layers.labels._labels_utils import get_contours
 from napari.utils import Colormap
+from napari.utils._test_utils import (
+    validate_all_params_in_docstring,
+    validate_kwargs_sorted,
+)
 from napari.utils.colormaps import (
     CyclicLabelColormap,
     DirectLabelColormap,
@@ -28,7 +31,7 @@ from napari.utils.colormaps import (
 )
 
 
-@pytest.fixture
+@pytest.fixture()
 def direct_colormap():
     """Return a DirectLabelColormap."""
     return DirectLabelColormap(
@@ -41,7 +44,7 @@ def direct_colormap():
     )
 
 
-@pytest.fixture
+@pytest.fixture()
 def random_colormap():
     """Return a LabelColormap."""
     return label_colormap(50)
@@ -53,9 +56,9 @@ def test_random_labels():
     np.random.seed(0)
     data = np.random.randint(20, size=shape)
     layer = Labels(data)
-    assert np.all(layer.data == data)
+    np.testing.assert_array_equal(layer.data, data)
     assert layer.ndim == len(shape)
-    np.testing.assert_array_equal(layer.extent.data[1], shape)
+    np.testing.assert_array_equal(layer.extent.data[1], [s - 1 for s in shape])
     assert layer._data_view.shape == shape[-2:]
     assert layer.editable is True
 
@@ -65,9 +68,9 @@ def test_all_zeros_labels():
     shape = (10, 15)
     data = np.zeros(shape, dtype=int)
     layer = Labels(data)
-    assert np.all(layer.data == data)
+    np.testing.assert_array_equal(layer.data, data)
     assert layer.ndim == len(shape)
-    np.testing.assert_array_equal(layer.extent.data[1], shape)
+    np.testing.assert_array_equal(layer.extent.data[1], [s - 1 for s in shape])
     assert layer._data_view.shape == shape[-2:]
 
 
@@ -77,14 +80,13 @@ def test_3D_labels():
     np.random.seed(0)
     data = np.random.randint(20, size=shape)
     layer = Labels(data)
-    assert np.all(layer.data == data)
+    np.testing.assert_array_equal(layer.data, data)
     assert layer.ndim == len(shape)
-    np.testing.assert_array_equal(layer.extent.data[1], shape)
+    np.testing.assert_array_equal(layer.extent.data[1], [s - 1 for s in shape])
     assert layer._data_view.shape == shape[-2:]
     assert layer.editable is True
 
-    layer._slice_dims(ndisplay=3)
-    assert layer._slice_input.ndisplay == 3
+    layer._slice_dims(Dims(ndim=3, ndisplay=3))
     assert layer.editable is True
     assert layer.mode == 'pan_zoom'
 
@@ -107,13 +109,13 @@ def test_bool_labels():
     """Test instantiating labels layer with bools"""
     data = np.zeros((10, 10), dtype=bool)
     layer = Labels(data)
-    assert issubdtype(layer.data.dtype, np.integer)
+    assert np.issubdtype(layer.data.dtype, np.integer)
 
     data0 = np.zeros((20, 20), dtype=bool)
     data1 = data0[::2, ::2].astype(np.int32)
     data = [data0, data1]
     layer = Labels(data)
-    assert all(issubdtype(d.dtype, np.integer) for d in layer.data)
+    assert all(np.issubdtype(d.dtype, np.integer) for d in layer.data)
 
 
 def test_changing_labels():
@@ -126,9 +128,11 @@ def test_changing_labels():
     data_b = np.random.randint(20, size=shape_b)
     layer = Labels(data_a)
     layer.data = data_b
-    assert np.all(layer.data == data_b)
+    np.testing.assert_array_equal(layer.data, data_b)
     assert layer.ndim == len(shape_b)
-    np.testing.assert_array_equal(layer.extent.data[1], shape_b)
+    np.testing.assert_array_equal(
+        layer.extent.data[1], [s - 1 for s in shape_b]
+    )
     assert layer._data_view.shape == shape_b[-2:]
 
     data_c = np.zeros(shape_c, dtype=bool)
@@ -150,9 +154,11 @@ def test_changing_labels_dims():
     layer = Labels(data_a)
 
     layer.data = data_b
-    assert np.all(layer.data == data_b)
+    np.testing.assert_array_equal(layer.data, data_b)
     assert layer.ndim == len(shape_b)
-    np.testing.assert_array_equal(layer.extent.data[1], shape_b)
+    np.testing.assert_array_equal(
+        layer.extent.data[1], [s - 1 for s in shape_b]
+    )
     assert layer._data_view.shape == shape_b[-2:]
 
 
@@ -176,6 +182,10 @@ def test_changing_modes():
     assert layer.mode == 'pick'
     assert layer.mouse_pan is False
 
+    layer.mode = 'polygon'
+    assert layer.mode == 'polygon'
+    assert layer.mouse_pan is False
+
     layer.mode = 'pan_zoom'
     assert layer.mode == 'pan_zoom'
     assert layer.mouse_pan is True
@@ -252,57 +262,7 @@ def test_blending():
     assert layer.blending == 'opaque'
 
 
-@pytest.mark.filterwarnings("ignore:.*seed is deprecated.*")
-def test_seed():
-    """Test setting seed."""
-    np.random.seed(0)
-    data = np.random.randint(20, size=(10, 15))
-    layer = Labels(data)
-    assert layer.seed == 0.5
-
-    layer.seed = 0.9
-    assert layer.seed == 0.9
-
-    layer = Labels(data, seed=0.7)
-    assert layer.seed == 0.7
-
-    # ensure setting seed updates the random colormap
-    mapped_07 = layer.colormap.map(layer.data)
-    layer.seed = 0.4
-    mapped_04 = layer.colormap.map(layer.data)
-    assert_raises(
-        AssertionError, assert_array_almost_equal, mapped_07, mapped_04
-    )
-
-
-def test_num_colors():
-    """Test setting number of colors in colormap with deprecated API."""
-    np.random.seed(0)
-    data = np.random.randint(20, size=(10, 15))
-    layer = Labels(data)
-
-    with pytest.warns(FutureWarning, match='num_colors is deprecated'):
-        assert layer.num_colors == 50
-
-    with pytest.warns(FutureWarning, match='num_colors is deprecated'):
-        layer.num_colors = 80
-
-    assert len(layer.colormap) == 80
-
-    with pytest.warns(FutureWarning, match='num_colors is deprecated'):
-        layer = Labels(data, num_colors=60)
-
-    assert len(layer.colormap) == 60
-
-    with pytest.raises(ValueError, match=r".*Only up to 2\*\*16=65535 colors"):
-        with pytest.warns(FutureWarning, match='num_colors is deprecated'):
-            layer.num_colors = 2**17
-
-    with pytest.raises(ValueError, match=r".*Only up to 2\*\*16=65535 colors"):
-        with pytest.warns(FutureWarning, match='num_colors is deprecated'):
-            Labels(data, num_colors=2**17)
-
-
+@pytest.mark.filterwarnings('ignore:.*seed is deprecated.*')
 def test_properties():
     """Test adding labels with properties."""
     np.random.seed(0)
@@ -333,7 +293,7 @@ def test_properties():
     properties = {'class': ['Background']}
     layer = Labels(data, properties=properties)
     layer_message = layer.get_status((0, 0))
-    assert layer_message['coordinates'].endswith("[No Properties]")
+    assert layer_message['coordinates'].endswith('[No Properties]')
 
     properties = {'class': ['Background', 'Class 12'], 'index': [0, 12]}
     label_index = {0: 0, 12: 1}
@@ -394,7 +354,7 @@ def test_multiscale_properties():
     properties = {'class': ['Background']}
     layer = Labels(data, properties=properties)
     layer_message = layer.get_status((0, 0))
-    assert layer_message['coordinates'].endswith("[No Properties]")
+    assert layer_message['coordinates'].endswith('[No Properties]')
 
     properties = {'class': ['Background', 'Class 12'], 'index': [0, 12]}
     label_index = {0: 0, 12: 1}
@@ -439,26 +399,46 @@ def test_custom_color_dict():
     """Test custom color dict."""
     np.random.seed(0)
     data = np.random.randint(20, size=(10, 15))
-    with pytest.warns(FutureWarning, match='Labels.color is deprecated'):
-        layer = Labels(
-            data,
-            color={2: 'white', 4: 'red', 8: 'blue', 16: 'red', 32: 'blue'},
+    cmap = DirectLabelColormap(
+        color_dict=defaultdict(
+            lambda: 'black',
+            {2: 'white', 4: 'red', 8: 'blue', 16: 'red', 32: 'blue'},
         )
+    )
+    layer = Labels(data, colormap=cmap)
 
     # test with custom color dict
-    assert type(layer.get_color(2)) == np.ndarray
-    assert type(layer.get_color(1)) == np.ndarray
+    assert isinstance(layer.get_color(2), np.ndarray)
+    assert isinstance(layer.get_color(1), np.ndarray)
     assert (layer.get_color(2) == np.array([1.0, 1.0, 1.0, 1.0])).all()
     assert (layer.get_color(4) == layer.get_color(16)).all()
     assert (layer.get_color(8) == layer.get_color(32)).all()
 
     # test disable custom color dict
     # should not initialize as white since we are using random.seed
-    with pytest.warns(FutureWarning, match='Labels.color_mode is deprecated'):
-        layer.color_mode = 'auto'
     assert not (layer.get_color(1) == np.array([1.0, 1.0, 1.0, 1.0])).all()
 
 
+@pytest.mark.parametrize(
+    'colormap_like',
+    [
+        ['red', 'blue'],
+        [[1, 0, 0, 1], [0, 0, 1, 1]],
+        {None: 'transparent', 1: 'red', 2: 'blue'},
+        {None: [0, 0, 0, 0], 1: [1, 0, 0, 1], 2: [0, 0, 1, 1]},
+        defaultdict(lambda: 'transparent', {1: 'red', 2: 'blue'}),
+    ],
+)
+def test_colormap_simple_data_types(colormap_like):
+    """Test that setting colormap with list or dict of colors works."""
+    data = np.random.randint(20, size=(10, 15))
+    # test in constructor
+    _ = Labels(data, colormap=colormap_like)
+    # test assignment
+    layer = Labels(data)
+    layer.colormap = colormap_like
+
+
 def test_metadata():
     """Test setting labels metadata."""
     np.random.seed(0)
@@ -502,7 +482,7 @@ def test_n_edit_dimensions():
 
 
 @pytest.mark.parametrize(
-    "input_data, expected_data_view",
+    ('input_data', 'expected_data_view'),
     [
         (
             np.array(
@@ -617,7 +597,7 @@ def test_contour(input_data, expected_data_view):
         layer.contour = -1
 
 
-@pytest.mark.parametrize("background_num", [0, 1, 2, -1])
+@pytest.mark.parametrize('background_num', [0, 1, 2, -1])
 def test_background_label(background_num):
     data = np.zeros((10, 10), dtype=np.int32)
     data[1:-1, 1:-1] = 1
@@ -679,8 +659,8 @@ def test_contour_local_updates():
 
     layer.data_setitem(np.nonzero(painting_mask), 1, refresh=True)
 
-    assert np.alltrue(
-        (layer._slice.image.view > 0) == get_contours(painting_mask, 1, 0)
+    assert np.array_equiv(
+        (layer._slice.image.view > 0), get_contours(painting_mask, 1, 0)
     )
 
 
@@ -701,8 +681,9 @@ def test_data_setitem_multi_dim():
 def test_data_setitiem_transposed_axes():
     data = np.zeros((10, 100), dtype=np.uint32)
     labels = Labels(data)
+    dims = Dims(ndim=2, ndisplay=2, order=(1, 0))
     labels.data_setitem((np.array([9]), np.array([99])), 1)
-    labels._slice_dims([0, 0], 2, [1, 0])
+    labels._slice_dims(dims)
     labels.data_setitem((np.array([9]), np.array([99])), 2)
 
 
@@ -843,7 +824,7 @@ def test_paint_2d_xarray():
     assert isinstance(layer.data, xr.DataArray)
     assert layer.data.sum() == 411
     elapsed = time.monotonic() - now
-    assert elapsed < 1, "test was too slow, computation was likely not lazy"
+    assert elapsed < 1, 'test was too slow, computation was likely not lazy'
 
 
 def test_paint_3d():
@@ -870,6 +851,66 @@ def test_paint_3d():
     assert np.sum(layer.data[4:17, 9:32, 9:32] == 5) == 1103
 
 
+def test_paint_polygon():
+    """Test painting labels with polygons."""
+    data = np.zeros((10, 15), dtype=int)
+    data[:10, :10] = 1
+    layer = Labels(data)
+
+    layer.paint_polygon([[0, 0], [0, 5], [5, 5], [5, 0]], 2)
+    assert np.array_equiv(layer.data[:5, :5], 2)
+    assert np.array_equiv(layer.data[:10, 6:10], 1)
+    assert np.array_equiv(layer.data[6:10, :10], 1)
+
+    layer.paint_polygon([[7, 7], [7, 7], [7, 7]], 3)
+    assert layer.data[7, 7] == 3
+    assert np.array_equiv(
+        layer.data[[6, 7, 8, 7, 8, 6], [7, 6, 7, 8, 8, 6]], 1
+    )
+
+    data[:10, :10] = 0
+    gt_pattern = np.array(
+        [
+            [0, 0, 0, 0, 0, 0, 0, 0],
+            [0, 1, 1, 1, 1, 1, 1, 0],
+            [0, 1, 1, 1, 1, 1, 1, 0],
+            [0, 1, 1, 0, 0, 1, 1, 0],
+            [0, 1, 1, 0, 0, 1, 1, 0],
+            [0, 1, 1, 0, 0, 1, 1, 0],
+            [0, 0, 0, 0, 0, 0, 0, 0],
+        ]
+    )
+    polygon_points = [
+        [1, 1],
+        [1, 6],
+        [5, 6],
+        [5, 5],
+        [2, 5],
+        [2, 2],
+        [5, 2],
+        [5, 1],
+    ]
+    layer.paint_polygon(polygon_points, 1)
+    assert np.allclose(layer.data[:7, :8], gt_pattern)
+
+    data[:10, :10] = 0
+    layer.paint_polygon(polygon_points[::-1], 1)
+    assert np.allclose(layer.data[:7, :8], gt_pattern)
+
+
+def test_paint_polygon_2d_in_3d():
+    """Test painting labels with polygons in a 3D array"""
+    data = np.zeros((3, 10, 10), dtype=int)
+    layer = Labels(data)
+
+    assert layer.n_edit_dimensions == 2
+
+    layer.paint_polygon([[1, 0, 0], [1, 0, 9], [1, 9, 9], [1, 9, 0]], 1)
+
+    assert np.array_equiv(data[1, :], 1)
+    assert np.array_equiv(data[[0, 2], :], 0)
+
+
 def test_fill():
     """Test filling labels with different brush sizes."""
     np.random.seed(0)
@@ -895,7 +936,7 @@ def test_value():
 
 
 @pytest.mark.parametrize(
-    'position,view_direction,dims_displayed,world',
+    ('position', 'view_direction', 'dims_displayed', 'world'),
     [
         ([10, 5, 5], [1, 0, 0], [0, 1, 2], False),
         ([10, 5, 5], [1, 0, 0], [0, 1, 2], True),
@@ -907,7 +948,7 @@ def test_value_3d(position, view_direction, dims_displayed, world):
     data = np.zeros((20, 20, 20), dtype=int)
     data[0:10, 0:10, 0:10] = 1
     layer = Labels(data)
-    layer._slice_dims([0, 0, 0], ndisplay=3)
+    layer._slice_dims(Dims(ndim=3, ndisplay=3))
     value = layer.get_value(
         position,
         view_direction=view_direction,
@@ -935,8 +976,8 @@ def test_thumbnail():
     assert layer.thumbnail.shape == layer._thumbnail_shape
 
 
-@pytest.mark.parametrize("value", [1, 10, 50, -2, -10])
-@pytest.mark.parametrize("dtype", [np.int8, np.int32])
+@pytest.mark.parametrize('value', [1, 10, 50, -2, -10])
+@pytest.mark.parametrize('dtype', [np.int8, np.int32])
 def test_thumbnail_single_color(value, dtype):
     labels = Labels(np.full((10, 10), value, dtype=dtype), opacity=1)
     labels._update_thumbnail()
@@ -952,12 +993,18 @@ def test_world_data_extent():
     shape = (6, 10, 15)
     data = np.random.randint(20, size=shape)
     layer = Labels(data)
-    extent = np.array(((0,) * 3, shape))
-    check_layer_world_data_extent(layer, extent, (3, 1, 1), (10, 20, 5), True)
+    extent = np.array(((0,) * 3, [s - 1 for s in shape]))
+    check_layer_world_data_extent(layer, extent, (3, 1, 1), (10, 20, 5))
 
 
 @pytest.mark.parametrize(
-    'brush_size, mode, selected_label, preserve_labels, n_dimensional',
+    (
+        'brush_size',
+        'mode',
+        'selected_label',
+        'preserve_labels',
+        'n_dimensional',
+    ),
     list(
         itertools.product(
             list(range(1, 22, 5)),
@@ -1028,10 +1075,11 @@ def test_ndim_paint():
     layer.paint((1, 1, 1, 1), 1)
 
     assert np.sum(layer.data) == 19  # 18 + center
-    assert not np.any(layer.data[0]) and not np.any(layer.data[2:])
+    assert not np.any(layer.data[0])
+    assert not np.any(layer.data[2:])
 
     layer.n_edit_dimensions = 2  # 3x3 square
-    layer._slice_dims(order=[1, 2, 0, 3])
+    layer._slice_dims(Dims(ndim=4, order=(1, 2, 0, 3)))
     layer.paint((4, 5, 6, 7), 8)
     assert len(np.flatnonzero(layer.data == 8)) == 4  # 2D square is in corner
     np.testing.assert_array_equal(
@@ -1054,9 +1102,6 @@ def test_cursor_size_with_negative_scale():
     assert layer.cursor_size > 0
 
 
-@pytest.mark.xfail(
-    reason="labels are converted to float32 before being mapped"
-)
 def test_large_label_values():
     label_array = 2**23 + np.arange(4, dtype=np.uint64).reshape((2, 2))
     layer = Labels(label_array)
@@ -1153,11 +1198,11 @@ def test_3d_video_and_3d_scale_translate_then_scale_translate_padded():
 @dataclass
 class MouseEvent:
     # mock mouse event class
-    pos: List[int]
-    position: List[int]
-    dims_point: List[int]
-    dims_displayed: List[int]
-    view_direction: List[int]
+    pos: list[int]
+    position: list[int]
+    dims_point: list[int]
+    dims_displayed: list[int]
+    view_direction: list[int]
 
 
 def test_get_value_ray_3d():
@@ -1175,7 +1220,7 @@ def test_get_value_ray_3d():
     labels = Labels(data, scale=(1, 2, 1, 1), translate=(5, 5, 5))
 
     # set the dims to the slice with labels
-    labels._slice_dims([1, 0, 0, 0], ndisplay=3)
+    labels._slice_dims(Dims(ndim=4, ndisplay=3, point=(1, 0, 0, 0)))
 
     value = labels._get_value_ray(
         start_point=np.array([1, 0, 5, 5]),
@@ -1193,7 +1238,7 @@ def test_get_value_ray_3d():
     assert value is None
 
     # set the dims to a slice without labels
-    labels._slice_dims([0, 0, 0, 0], ndisplay=3)
+    labels._slice_dims(Dims(ndim=4, ndisplay=3, point=(0, 0, 0, 0)))
 
     value = labels._get_value_ray(
         start_point=np.array([0, 0, 5, 5]),
@@ -1220,7 +1265,9 @@ def test_get_value_ray_3d_rolled():
     labels = Labels(data, scale=(1, 2, 1, 1), translate=(5, 5, 5, 0))
 
     # set the dims to the slice with labels
-    labels._slice_dims((0, 0, 0, 1), ndisplay=3, order=(3, 0, 1, 2))
+    labels._slice_dims(
+        Dims(ndim=4, ndisplay=3, order=(3, 0, 1, 2), point=(0, 0, 0, 1))
+    )
     labels.set_view_slice()
 
     value = labels._get_value_ray(
@@ -1248,7 +1295,9 @@ def test_get_value_ray_3d_transposed():
     labels = Labels(data, scale=(1, 2, 1, 1), translate=(0, 5, 5, 5))
 
     # set the dims to the slice with labels
-    labels._slice_dims((1, 0, 0, 0), ndisplay=3, order=(0, 1, 3, 2))
+    labels._slice_dims(
+        Dims(ndim=4, ndisplay=3, order=(0, 1, 3, 2), point=(1, 0, 0, 0))
+    )
     labels.set_view_slice()
 
     value = labels._get_value_ray(
@@ -1276,7 +1325,7 @@ def test_get_value_ray_2d():
     labels = Labels(data, scale=(1, 2, 1, 1), translate=(5, 5, 5))
 
     # set the dims to the slice with labels, but 2D
-    labels._slice_dims([1, 10, 0, 0], ndisplay=2)
+    labels._slice_dims(Dims(ndim=4, ndisplay=2, point=(1, 10, 0, 0)))
 
     value = labels._get_value_ray(
         start_point=np.empty([]),
@@ -1300,7 +1349,7 @@ def test_cursor_ray_3d():
     labels = Labels(data, scale=(1, 1, 2, 1), translate=(5, 5, 5))
 
     # set the slice to one with data and the view to 3D
-    labels._slice_dims([1, 0, 0, 0], ndisplay=3)
+    labels._slice_dims(Dims(ndim=4, ndisplay=3, point=(1, 0, 0, 0)))
 
     # axis 0 : [0, 20], bounding box extents along view axis, [1, 0, 0]
     # click is transformed: (value - translation) / scale
@@ -1338,7 +1387,7 @@ def test_cursor_ray_3d():
         dims_displayed=[1, 2, 3],
         view_direction=[0, 1, 0, 0],
     )
-    labels._slice_dims([0, 0, 0, 0], ndisplay=3)
+    labels._slice_dims(Dims(ndim=4, ndisplay=3))
     start_point, end_point = labels.get_ray_intersections(
         mouse_event_3.position,
         mouse_event_3.view_direction,
@@ -1365,7 +1414,7 @@ def test_cursor_ray_3d_rolled():
     labels = Labels(data, scale=(1, 2, 1, 1), translate=(5, 5, 5, 0))
 
     # set the slice to one with data and the view to 3D
-    labels._slice_dims([0, 0, 0, 1], ndisplay=3)
+    labels._slice_dims(Dims(ndim=4, ndisplay=3, point=(0, 0, 0, 1)))
 
     start_point, end_point = labels.get_ray_intersections(
         mouse_event_1.position,
@@ -1393,7 +1442,7 @@ def test_cursor_ray_3d_transposed():
     labels = Labels(data, scale=(1, 2, 1, 1), translate=(5, 5, 5, 0))
 
     # set the slice to one with data and the view to 3D
-    labels._slice_dims([0, 0, 0, 1], ndisplay=3)
+    labels._slice_dims(Dims(ndim=4, ndisplay=3, point=(0, 0, 0, 1)))
 
     start_point, end_point = labels.get_ray_intersections(
         mouse_event_1.position,
@@ -1438,8 +1487,6 @@ def test_is_default_color():
     # setting color to default colors doesn't update color mode
     layer.colormap = DirectLabelColormap(color_dict=current_color)
     assert isinstance(layer.colormap, CyclicLabelColormap)
-    with pytest.warns(FutureWarning, match='Labels.color_mode is deprecated'):
-        assert layer.color_mode == 'auto'
 
     # new colors are not default
     new_color = {0: 'white', 1: 'red', 3: 'green', None: 'blue'}
@@ -1447,8 +1494,6 @@ def test_is_default_color():
     # setting the color with non-default colors updates color mode
     layer.colormap = DirectLabelColormap(color_dict=new_color)
     assert isinstance(layer.colormap, DirectLabelColormap)
-    with pytest.warns(FutureWarning, match='Labels.color_mode is deprecated'):
-        assert layer.color_mode == 'direct'
 
 
 def test_large_labels_direct_color():
@@ -1456,12 +1501,12 @@ def test_large_labels_direct_color():
     pytest.importorskip('numba')
     data = np.array([[0, 1], [2**16, 2**20]], dtype=np.uint32)
     colors = {1: 'white', 2**16: 'green', 2**20: 'magenta'}
-    layer = Labels(data)
-    with pytest.warns(FutureWarning, match='Labels.color is deprecated'):
-        layer.color = colors
-
-    with pytest.warns(FutureWarning, match='Labels.color_mode is deprecated'):
-        assert layer.color_mode == 'direct'
+    layer = Labels(
+        data,
+        colormap=DirectLabelColormap(
+            color_dict=defaultdict(lambda: 'black', colors)
+        ),
+    )
     np.testing.assert_allclose(layer.get_color(2**20), [1.0, 0.0, 1.0, 1.0])
 
 
@@ -1593,7 +1638,7 @@ def test_negative_label_slicing():
     data = np.array([[[0, 1], [-1, -1]], [[100, 100], [-1, -2]]])
     layer = Labels(data)
     assert tuple(layer.get_color(1)) != tuple(layer.get_color(-1))
-    layer._slice_dims(point=(1, 0, 0))
+    layer._slice_dims(Dims(ndim=3, point=(1, 0, 0)))
     assert tuple(layer.get_color(-1)) != tuple(layer.get_color(100))
     assert tuple(layer.get_color(-2)) != tuple(layer.get_color(100))
 
@@ -1607,7 +1652,7 @@ def test_negative_label_doesnt_flicker():
         ]
     )
     layer = Labels(data)
-    layer._slice_dims(point=(1, 0, 0))
+    layer._slice_dims(Dims(ndim=3, point=(1, 0, 0)))
     # This used to fail when negative values were used to index into _all_vals.
     assert tuple(layer.get_color(-1)) != tuple(layer.get_color(5))
     minus_one_color_original = tuple(layer.get_color(-1))
@@ -1664,7 +1709,7 @@ def test_copy():
 
 
 @pytest.mark.parametrize(
-    "colormap,expected",
+    ('colormap', 'expected'),
     [
         (label_colormap(49, 0.5), [0, 1]),
         (
@@ -1678,11 +1723,11 @@ def test_copy():
             [1, 2],
         ),
     ],
-    ids=["auto", "direct"],
+    ids=['auto', 'direct'],
 )
 def test_draw(colormap, expected):
     labels = Labels(np.zeros((30, 30), dtype=np.uint32))
-    labels.mode = "paint"
+    labels.mode = 'paint'
     labels.colormap = colormap
     labels.selected_label = 1
     npt.assert_array_equal(np.unique(labels._slice.image.raw), [0])
@@ -1700,5 +1745,10 @@ class TestLabels:
     def test_events_defined(self, event_define_check, obj):
         event_define_check(
             obj,
-            {"seed", "num_colors", "color", "seed_rng"},
+            {'seed', 'num_colors', 'color', 'seed_rng'},
         )
+
+
+def test_docstring():
+    validate_all_params_in_docstring(Labels)
+    validate_kwargs_sorted(Labels)
