@@ -12,7 +12,6 @@ from napari.layers.utils.layer_utils import (
     dataframe_to_properties,
     dims_displayed_world_to_layer,
     get_current_properties,
-    prepare_properties,
     register_layer_attr_action,
     segment_normal,
 )
@@ -37,40 +36,46 @@ def test_calc_data_range():
     # all zeros should return [0, 1] by default
     data = np.zeros((10, 10))
     clim = calc_data_range(data)
-    assert np.all(clim == [0, 1])
+    np.testing.assert_array_equal(clim, (0, 1))
 
     # all ones should return [0, 1] by default
     data = np.ones((10, 10))
     clim = calc_data_range(data)
-    assert np.all(clim == [0, 1])
+    np.testing.assert_array_equal(clim, (0, 1))
 
     # return min and max
     data = np.random.random((10, 15))
     data[0, 0] = 0
     data[0, 1] = 2
     clim = calc_data_range(data)
-    assert np.all(clim == [0, 2])
+    np.testing.assert_array_equal(clim, (0, 2))
 
     # return min and max
     data = np.random.random((6, 10, 15))
     data[0, 0, 0] = 0
     data[0, 0, 1] = 2
     clim = calc_data_range(data)
-    assert np.all(clim == [0, 2])
+    np.testing.assert_array_equal(clim, (0, 2))
 
     # Try large data
     data = np.zeros((1000, 2000))
     data[0, 0] = 0
     data[0, 1] = 2
     clim = calc_data_range(data)
-    assert np.all(clim == [0, 2])
+    np.testing.assert_array_equal(clim, (0, 2))
 
-    # Try large data mutlidimensional
+    # Try large data multidimensional
     data = np.zeros((3, 1000, 1000))
     data[0, 0, 0] = 0
     data[0, 0, 1] = 2
     clim = calc_data_range(data)
-    assert np.all(clim == [0, 2])
+    np.testing.assert_array_equal(clim, (0, 2))
+
+    data = np.zeros((10_000, 10_000))
+    data[0, 0] = -1
+    data[-1, -1] = 10
+    clim = calc_data_range(data)
+    np.testing.assert_array_equal(clim, (-1, 10))
 
 
 @pytest.mark.parametrize(
@@ -82,7 +87,7 @@ def test_calc_data_range_fast(data):
     val = calc_data_range(data)
     assert len(val) > 0
     elapsed = time.monotonic() - now
-    assert elapsed < 5, "test took too long, computation was likely not lazy"
+    assert elapsed < 5, 'test took too long, computation was likely not lazy'
 
 
 def test_segment_normal_2d():
@@ -90,7 +95,7 @@ def test_segment_normal_2d():
     b = np.array([1, 10])
 
     unit_norm = segment_normal(a, b)
-    assert np.all(unit_norm == np.array([1, 0]))
+    np.testing.assert_array_equal(unit_norm, np.array([1, 0]))
 
 
 def test_segment_normal_3d():
@@ -99,7 +104,7 @@ def test_segment_normal_3d():
     p = np.array([1, 0, 0])
 
     unit_norm = segment_normal(a, b, p)
-    assert np.all(unit_norm == np.array([0, 0, -1]))
+    np.testing.assert_array_equal(unit_norm, np.array([0, 0, -1]))
 
 
 def test_dataframe_to_properties():
@@ -109,93 +114,28 @@ def test_dataframe_to_properties():
     np.testing.assert_equal(converted_properties, properties)
 
 
-def test_prepare_properties_with_empty_properties():
-    assert prepare_properties({}) == ({}, {})
-
-
-def test_prepare_properties_with_empty_properties_and_choices():
-    assert prepare_properties({}, {}) == ({}, {})
-
-
-def test_prepare_properties_with_properties_then_choices_from_properties():
-    properties, choices = prepare_properties({"aa": [1, 2]}, num_data=2)
-    assert list(properties.keys()) == ["aa"]
-    assert np.array_equal(properties["aa"], [1, 2])
-    assert list(choices.keys()) == ["aa"]
-    assert np.array_equal(choices["aa"], [1, 2])
-
-
-def test_prepare_properties_with_choices_then_properties_are_none():
-    properties, choices = prepare_properties({}, {"aa": [1, 2]}, num_data=2)
-    assert list(properties.keys()) == ["aa"]
-    assert np.array_equal(properties["aa"], [None, None])
-    assert list(choices.keys()) == ["aa"]
-    assert np.array_equal(choices["aa"], [1, 2])
-
-
-def test_prepare_properties_with_properties_and_choices():
-    properties, choices = prepare_properties({"aa": [1, 2, 1]}, num_data=3)
-    assert np.array_equal(properties["aa"], [1, 2, 1])
-    assert np.array_equal(choices["aa"], [1, 2])
-
-
-def test_prepare_properties_with_properties_and_choices_then_merge_choice_values():
-    properties, choices = prepare_properties(
-        {"aa": [1, 3]}, {"aa": [1, 2]}, num_data=2
-    )
-    assert list(properties.keys()) == ["aa"]
-    assert np.array_equal(properties["aa"], [1, 3])
-    assert list(choices.keys()) == ["aa"]
-    assert np.array_equal(choices["aa"], [1, 2, 3])
-
-
-def test_prepare_properties_with_properties_and_choices_then_skip_choice_keys():
-    properties, choices = prepare_properties(
-        {"aa": [1, 3]}, {"aa": [1, 2], "bb": [7, 6]}, num_data=2
-    )
-    assert list(properties.keys()) == ["aa"]
-    assert np.array_equal(properties["aa"], [1, 3])
-    assert list(choices.keys()) == ["aa"]
-    assert np.array_equal(choices["aa"], [1, 2, 3])
-
-
-def test_prepare_properties_with_properties_and_choices_and_save_choices():
-    properties, choices = prepare_properties(
-        {"aa": [1, 3]},
-        {"aa": [1, 2], "bb": [7, 6]},
-        num_data=2,
-        save_choices=True,
-    )
-    assert list(properties.keys()) == ["aa", "bb"]
-    assert np.array_equal(properties["aa"], [1, 3])
-    assert np.array_equal(properties["bb"], [None, None])
-    assert list(choices.keys()) == ["aa", "bb"]
-    assert np.array_equal(choices["aa"], [1, 2, 3])
-    assert np.array_equal(choices["bb"], [6, 7])
-
-
 def test_get_current_properties_with_properties_then_last_values():
     properties = {
-        "face_color": np.array(["cyan", "red", "red"]),
-        "angle": np.array([0.5, 1.5, 1.5]),
+        'face_color': np.array(['cyan', 'red', 'red']),
+        'angle': np.array([0.5, 1.5, 1.5]),
     }
 
     current_properties = get_current_properties(properties, {}, 3)
 
     assert current_properties == {
-        "face_color": "red",
-        "angle": 1.5,
+        'face_color': 'red',
+        'angle': 1.5,
     }
 
 
 def test_get_current_properties_with_property_choices_then_first_values():
     properties = {
-        "face_color": np.empty(0, dtype=str),
-        "angle": np.empty(0, dtype=float),
+        'face_color': np.empty(0, dtype=str),
+        'angle': np.empty(0, dtype=float),
     }
     property_choices = {
-        "face_color": np.array(["cyan", "red"]),
-        "angle": np.array([0.5, 1.5]),
+        'face_color': np.array(['cyan', 'red']),
+        'angle': np.array([0.5, 1.5]),
     }
 
     current_properties = get_current_properties(
@@ -204,8 +144,8 @@ def test_get_current_properties_with_property_choices_then_first_values():
     )
 
     assert current_properties == {
-        "face_color": "cyan",
-        "angle": 0.5,
+        'face_color': 'cyan',
+        'angle': 0.5,
     }
 
 
@@ -238,12 +178,12 @@ def test_coerce_current_properties_invalid_values():
         'model': np.array(['best', 'best_v2_final']),
     }
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='should have length 1'):
         _ = coerce_current_properties(current_properties)
 
 
 @pytest.mark.parametrize(
-    "dims_displayed,ndim_world,ndim_layer,expected",
+    ('dims_displayed', 'ndim_world', 'ndim_layer', 'expected'),
     [
         ([1, 2, 3], 4, 4, [1, 2, 3]),
         ([0, 1, 2], 4, 4, [0, 1, 2]),
@@ -404,7 +344,7 @@ def test_feature_table_from_layer_with_properties_as_dataframe():
     pd.testing.assert_frame_equal(feature_table.values, TEST_FEATURES)
 
 
-@pytest.fixture
+@pytest.fixture()
 def feature_table():
     return _FeatureTable(TEST_FEATURES.copy(deep=True), num_data=4)
 
@@ -515,19 +455,23 @@ def test_feature_table_set_defaults_with_same_columns(feature_table):
 def test_feature_table_set_defaults_with_extra_column(feature_table):
     defaults = {'class': 'building', 'confidence': 0, 'cat': 'kermit'}
     assert 'cat' not in feature_table.values.columns
-    with pytest.raises(ValueError):
+    with pytest.raises(
+        ValueError, match='extra columns not in feature values'
+    ):
         feature_table.set_defaults(defaults)
 
 
 def test_feature_table_set_defaults_with_missing_column(feature_table):
     defaults = {'class': 'building'}
     assert len(feature_table.values.columns) > 1
-    with pytest.raises(ValueError):
+    with pytest.raises(
+        ValueError, match='missing some columns in feature values'
+    ):
         feature_table.set_defaults(defaults)
 
 
 def test_register_label_attr_action(monkeypatch):
-    monkeypatch.setattr(time, "time", lambda: 1)
+    monkeypatch.setattr(time, 'time', lambda: 1)
 
     class Foo(KeymapProvider):
         def __init__(self) -> None:
@@ -539,18 +483,18 @@ def test_register_label_attr_action(monkeypatch):
     handler = KeymapHandler()
     handler.keymap_providers = [foo]
 
-    @register_layer_attr_action(Foo, "value desc", "value", "K")
+    @register_layer_attr_action(Foo, 'value desc', 'value', 'K')
     def set_value_1(x):
         x.value = 1
 
-    handler.press_key("K")
+    handler.press_key('K')
     assert foo.value == 1
-    handler.release_key("K")
+    handler.release_key('K')
     assert foo.value == 1
 
     foo.value = 0
-    handler.press_key("K")
+    handler.press_key('K')
     assert foo.value == 1
-    monkeypatch.setattr(time, "time", lambda: 2)
-    handler.release_key("K")
+    monkeypatch.setattr(time, 'time', lambda: 2)
+    handler.release_key('K')
     assert foo.value == 0
