@@ -1,20 +1,24 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, List, Tuple, Union
+from typing import TYPE_CHECKING, Union
 
 import numpy as np
+import numpy.typing as npt
 
-from ...utils.geometry import point_in_bounding_box, project_points_onto_plane
+from napari.utils.geometry import (
+    point_in_bounding_box,
+    project_points_onto_plane,
+)
 
 if TYPE_CHECKING:
-    from ..image.image import Image
+    from napari.layers.image.image import Image
 
 
 def displayed_plane_from_nd_line_segment(
-    start_point: np.ndarray,
-    end_point: np.ndarray,
-    dims_displayed: Union[List[int], np.ndarray],
-) -> Tuple[np.ndarray, np.ndarray]:
+    start_point: npt.NDArray,
+    end_point: npt.NDArray,
+    dims_displayed: Union[list[int], npt.NDArray],
+) -> tuple[npt.NDArray, npt.NDArray]:
     """Get the plane defined by start_point and the normal vector that goes
     from start_point to end_point.
 
@@ -47,8 +51,11 @@ def displayed_plane_from_nd_line_segment(
 
 
 def drag_data_to_projected_distance(
-    start_position, end_position, view_direction, vector
-):
+    start_position: npt.NDArray,
+    end_position: npt.NDArray,
+    view_direction: npt.NDArray,
+    vector: npt.NDArray,
+) -> npt.NDArray:
     """Calculate the projected distance between two mouse events.
 
     Project the drag vector between two mouse events onto a 3D vector
@@ -95,7 +102,9 @@ def drag_data_to_projected_distance(
     return np.einsum('j, ij -> i', drag_vector_canvas, vector).squeeze()
 
 
-def orient_plane_normal_around_cursor(layer: Image, plane_normal: tuple):
+def orient_plane_normal_around_cursor(
+    layer: Image, plane_normal: tuple
+) -> None:
     """Orient a rendering plane by rotating it around the cursor.
 
     If the cursor ray does not intersect the plane, the position will remain
@@ -110,10 +119,11 @@ def orient_plane_normal_around_cursor(layer: Image, plane_normal: tuple):
     """
     # avoid circular imports
     import napari
-
-    from ..image._image_constants import VolumeDepiction
+    from napari.layers.image._image_constants import VolumeDepiction
 
     viewer = napari.viewer.current_viewer()
+    if viewer is None:
+        return
 
     # early exit
     if viewer.dims.ndisplay != 3 or layer.depiction != VolumeDepiction.PLANE:
@@ -121,17 +131,18 @@ def orient_plane_normal_around_cursor(layer: Image, plane_normal: tuple):
 
     # find cursor-plane intersection in data coordinates
     cursor_position = layer._world_to_displayed_data(
-        position=viewer.cursor.position, dims_displayed=layer._dims_displayed
+        position=np.asarray(viewer.cursor.position),
+        dims_displayed=layer._slice_input.displayed,
     )
     view_direction = layer._world_to_displayed_data_ray(
-        viewer.camera.view_direction, dims_displayed=[-3, -2, -1]
+        np.asarray(viewer.camera.view_direction), dims_displayed=[-3, -2, -1]
     )
     intersection = layer.plane.intersect_with_line(
         line_position=cursor_position, line_direction=view_direction
     )
 
     # check if intersection is within data extents for displayed dimensions
-    bounding_box = layer.extent.data[:, layer._dims_displayed]
+    bounding_box = layer.extent.data[:, layer._slice_input.displayed]
 
     # update plane position
     if point_in_bounding_box(intersection, bounding_box):
@@ -139,15 +150,15 @@ def orient_plane_normal_around_cursor(layer: Image, plane_normal: tuple):
 
     # update plane normal
     layer.plane.normal = layer._world_to_displayed_data_ray(
-        plane_normal, dims_displayed=layer._dims_displayed
+        np.asarray(plane_normal), dims_displayed=layer._slice_input.displayed
     )
 
 
 def nd_line_segment_to_displayed_data_ray(
     start_point: np.ndarray,
     end_point: np.ndarray,
-    dims_displayed: Union[List[int], np.ndarray],
-) -> Tuple[np.ndarray, np.ndarray]:
+    dims_displayed: Union[list[int], np.ndarray],
+) -> tuple[np.ndarray, np.ndarray]:
     """Convert the start and end point of the line segment of a mouse click ray
     intersecting a data cube to a ray (i.e., start position and direction) in
     displayed data coordinates
