@@ -1,3 +1,4 @@
+# mypy: disable-error-code=empty-body
 """
 All napari hook specifications for pluggable functionality are defined here.
 
@@ -30,17 +31,18 @@ For more general background on the plugin hook calling mechanism, see the
     ``napari_hook_specification`` and ``napari_hook_implementation``,
     respectively.
 """
+
 # These hook specifications also serve as the API reference for plugin
 # developers, so comprehensive documentation with complete type annotations is
 # imperative!
 from __future__ import annotations
 
 from types import FunctionType
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Optional, Union
 
 from napari_plugin_engine import napari_hook_specification
 
-from ..types import (
+from napari.types import (
     AugmentedWidget,
     ReaderFunction,
     SampleData,
@@ -54,7 +56,7 @@ from ..types import (
 
 
 @napari_hook_specification(historic=True)
-def napari_provide_sample_data() -> Dict[str, Union[SampleData, SampleDict]]:
+def napari_provide_sample_data() -> dict[str, Union[SampleData, SampleDict]]:
     """Provide sample data.
 
     Plugins may implement this hook to provide sample data for use in napari.
@@ -77,9 +79,9 @@ def napari_provide_sample_data() -> Dict[str, Union[SampleData, SampleDict]]:
         1. random data from numpy
         2. a random image pulled from the internet
         3. random data from numpy, provided as a dict with the keys:
-            'display_name': a string that will show in the menu (by default,
+            * 'display_name': a string that will show in the menu (by default,
                 the `sample_key` will be shown)
-            'data': a string or callable, as in 1/2.
+            * 'data': a string or callable, as in 1/2.
 
     .. code-block:: python
 
@@ -109,7 +111,7 @@ def napari_provide_sample_data() -> Dict[str, Union[SampleData, SampleDict]]:
 
 
 @napari_hook_specification(firstresult=True)
-def napari_get_reader(path: Union[str, List[str]]) -> Optional[ReaderFunction]:
+def napari_get_reader(path: Union[str, list[str]]) -> Optional[ReaderFunction]:
     """Return a function capable of loading ``path`` into napari, or ``None``.
 
     This is the primary "**reader plugin**" function.  It accepts a path or
@@ -166,7 +168,7 @@ def napari_get_reader(path: Union[str, List[str]]) -> Optional[ReaderFunction]:
 
 @napari_hook_specification(firstresult=True)
 def napari_get_writer(
-    path: str, layer_types: List[str]
+    path: str, layer_types: list[str]
 ) -> Optional[WriterFunction]:
     """Return function capable of writing napari layer data to ``path``.
 
@@ -389,9 +391,9 @@ def napari_write_vectors(path: str, data: Any, meta: dict) -> Optional[str]:
 
 
 @napari_hook_specification(historic=True)
-def napari_experimental_provide_function() -> Union[
-    FunctionType, List[FunctionType]
-]:
+def napari_experimental_provide_function() -> (
+    Union[FunctionType, list[FunctionType]]
+):
     """Provide function(s) that can be passed to magicgui.
 
     This hook specification is marked as experimental as the API or how the
@@ -425,9 +427,9 @@ def napari_experimental_provide_function() -> Union[
 
 
 @napari_hook_specification(historic=True)
-def napari_experimental_provide_dock_widget() -> Union[
-    AugmentedWidget, List[AugmentedWidget]
-]:
+def napari_experimental_provide_dock_widget() -> (
+    Union[AugmentedWidget, list[AugmentedWidget]]
+):
     """Provide functions that return widgets to be docked in the viewer.
 
     This hook specification is marked as experimental as the API or how the
@@ -499,9 +501,9 @@ def napari_experimental_provide_dock_widget() -> Union[
 
 
 @napari_hook_specification(historic=True)
-def napari_experimental_provide_theme() -> Dict[
-    str, Dict[str, Union[str, Tuple, List]]
-]:
+def napari_experimental_provide_theme() -> (
+    dict[str, dict[str, Union[str, tuple, list]]]
+):
     """Provide GUI with a set of colors used through napari. This hook allows you to
     provide additional color schemes so you can accomplish your desired styling.
 
@@ -545,4 +547,5 @@ def napari_experimental_provide_theme() -> Dict[
     >>> @napari_hook_implementation
     >>> def napari_experimental_provide_theme():
     ...     return get_new_theme()
+
     """
